### 0.10.0 {small}`2024-03-26`

```{rubric} Features
```

* added `get` module {pr}`100` {smaller}`S Dicks`
* switch `utils` functions to `get` {pr}`100` {smaller}`S Dicks`
* added `get.aggregated` to create condensed `anndata` objects {pr}`100` {smaller}`S Dicks`
* added `pp.scrublet` and `pp.scrublet_simulate_doublets` {pr}`129` {smaller}`S Dicks`
* adds the option to return a copied `AnnData` for `get.anndata_to_CPU` & `get.anndata_to_GPU` {pr}`134` {smaller}`S Dicks`
* adds `mask` argument to `pp.scale` and `pp.pca` {pr}`135` {smaller}`S Dicks`
* adds the option to run `pp.scale` on sparse matrixes `zero_center = False` without densification {pr}`135` {smaller}`S Dicks`
* updated `ruff` and now requires parameters by name/keyword in all public APIs {pr}`140` {smaller}`S Dicks`
* adds the option to run `pp.harmony` with `np.float32` {pr}`145` {smaller}`S Dicks`

```{rubric} Bug fixes
```
* Fixes an issue where `pp.normalize` and `pp.log1p` now use `copy` and `inplace` correctly {pr}`129` {smaller}`S Dicks`
* changes the graph constructor for `tl.leiden` and `tl.louvain` {pr}`143` {smaller}`S Dicks`
* Added a test to handle zero features, that caused issues in the sparse `pp.pca` {pr}`144` {smaller}`S Dicks`
* Added a test to check if sparse matrices are in `canonical format`. For now this only affects `pp.highly_variable_genes`, `pp.scale` and `pp.normalize_pearson_residuals`. {pr}`146` {smaller}`S Dicks`

```{rubric} Removals
```
* Removed `cunnData` which was deprecated in `0.9.0`. Please use `AnnData` from now on. {pr}`130` {smaller}`S Dicks`
